==> haskell-mutable-containers-0.3.4.1-85-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-mutable-containers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 mutable-containers
version:              0.3.4.1
visibility:           public
id:                   mutable-containers-0.3.4.1-F12yQi4fGOEBsUkzxAxmhg
key:                  mutable-containers-0.3.4.1-F12yQi4fGOEBsUkzxAxmhg
license:              MIT
maintainer:           michael@fpcomplete.com
author:               Michael Snoyman
homepage:             https://github.com/snoyberg/mono-traversable#readme
synopsis:
    Abstactions and concrete implementations of mutable containers

description:
    See docs and README at <http://www.stackage.org/package/mutable-containers>

category:             Data
abi:                  9e04e335be7f6da3364b81aa37bfa827
exposed:              True
exposed-modules:      Data.Mutable
hidden-modules:
    Data.Mutable.BRef Data.Mutable.Class Data.Mutable.Deque
    Data.Mutable.DLList Data.Mutable.PRef Data.Mutable.SRef
    Data.Mutable.URef Paths_mutable_containers

import-dirs:          /usr/lib/ghc-9.2.8/site-local/mutable-containers-0.3.4.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/mutable-containers-0.3.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-mutable-containers
hs-libraries:         HSmutable-containers-0.3.4.1-F12yQi4fGOEBsUkzxAxmhg
depends:
    base-4.16.4.0 containers-0.6.5.1 ghc-prim-0.8.0
    mono-traversable-1.0.17.0-DrLlQD3bymdAhQ8ir5GYNX
    primitive-0.7.4.0-A9DQl7IN10ADdryf8HN1sF
    vector-0.13.1.0-FqETZo7rR6n5zX4PwJIjNh

haddock-interfaces:
    /usr/share/doc/haskell-mutable-containers/html/mutable-containers.haddock

haddock-html:         /usr/share/doc/haskell-mutable-containers/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-mutable-containers-0.3.4.1-97-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-mutable-containers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 mutable-containers
version:              0.3.4.1
visibility:           public
id:                   mutable-containers-0.3.4.1-6ffu8Jt0qkj1uhGxr9Ga8y
key:                  mutable-containers-0.3.4.1-6ffu8Jt0qkj1uhGxr9Ga8y
license:              MIT
maintainer:           michael@fpcomplete.com
author:               Michael Snoyman
homepage:             https://github.com/snoyberg/mono-traversable#readme
synopsis:
    Abstactions and concrete implementations of mutable containers

description:
    See docs and README at <http://www.stackage.org/package/mutable-containers>

category:             Data
abi:                  e65e49551dc3cc14694808c221114667
exposed:              True
exposed-modules:      Data.Mutable
hidden-modules:
    Data.Mutable.BRef Data.Mutable.Class Data.Mutable.Deque
    Data.Mutable.DLList Data.Mutable.PRef Data.Mutable.SRef
    Data.Mutable.URef Paths_mutable_containers

import-dirs:          /usr/lib/ghc-9.2.8/site-local/mutable-containers-0.3.4.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/mutable-containers-0.3.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-mutable-containers
hs-libraries:         HSmutable-containers-0.3.4.1-6ffu8Jt0qkj1uhGxr9Ga8y
depends:
    base-4.16.4.0 containers-0.6.5.1 ghc-prim-0.8.0
    mono-traversable-1.0.20.0-GPFeYG52X4x7t7TXdzuBJU
    primitive-0.7.4.0-AQ7cOoBXu5aBgAQTQzTLUx
    vector-0.13.1.0-xP3uH1g3cPFld8g0jCD5r

haddock-interfaces:
    /usr/share/doc/haskell-mutable-containers/html/mutable-containers.haddock

haddock-html:         /usr/share/doc/haskell-mutable-containers/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
